@@ -8,5 +8,6 @@ Mozilla Public License, version 2.0; see LICENSE.
 
 from .analysis import local_analysis
 from .analysis import occupancy_estimate
+from .analysis import ligand_validation
 
-__all__ = ['local_analysis', 'occupancy_estimate'] 
\ No newline at end of file
+__all__ = ['local_analysis', 'occupancy_estimate', 'ligand_validation'] 
\ No newline at end of file
